==> resin-4.0.53-sources.jar: com/caucho/distcache/jcache/CacheProviderImpl.java <==
/*
 * Copyright (c) 1998-2012 Caucho Technology -- all rights reserved
 *
 * This file is part of Resin(R) Open Source
 *
 * Each copy or derived work must preserve the copyright notice and this
 * notice unmodified.
 *
 * Resin Open Source is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Resin Open Source is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE, or any warranty
 * of NON-INFRINGEMENT.  See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Resin Open Source; if not, write to the
 *
 *   Free Software Foundation, Inc.
 *   59 Temple Place, Suite 330
 *   Boston, MA 02111-1307  USA
 *
 * @author Scott Ferguson
 */

package com.caucho.distcache.jcache;

import javax.cache.CacheManagerFactory;
import javax.cache.OptionalFeature;
import javax.cache.spi.CachingProvider;

/**
 * Caching Provider for jcache
 */
public class CacheProviderImpl implements CachingProvider
{
  private CacheManagerFactory _factory = new CacheManagerFactoryImpl();
  
  @Override
  public CacheManagerFactory getCacheManagerFactory()
  {
    return _factory;
  }
  
  @Override
  public boolean isSupported(OptionalFeature feature)
  {
    return false;
  }
}

==> resin-4.0.64-sources.jar: com/caucho/distcache/jcache/CacheProviderImpl.java <==
/*
 * Copyright (c) 1998-2018 Caucho Technology -- all rights reserved
 *
 * This file is part of Resin(R) Open Source
 *
 * Each copy or derived work must preserve the copyright notice and this
 * notice unmodified.
 *
 * Resin Open Source is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Resin Open Source is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE, or any warranty
 * of NON-INFRINGEMENT.  See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Resin Open Source; if not, write to the
 *
 *   Free Software Foundation, Inc.
 *   59 Temple Place, Suite 330
 *   Boston, MA 02111-1307  USA
 *
 * @author Scott Ferguson
 */

package com.caucho.distcache.jcache;

import com.caucho.cache.CacheManagerFactory;
import com.caucho.cache.OptionalFeature;
import com.caucho.cache.spi.CachingProvider;

/**
 * Caching Provider for jcache
 */
public class CacheProviderImpl implements CachingProvider
{
  private CacheManagerFactory _factory = new CacheManagerFactoryImpl();
  
  @Override
  public CacheManagerFactory getCacheManagerFactory()
  {
    return _factory;
  }
  
  @Override
  public boolean isSupported(OptionalFeature feature)
  {
    return false;
  }
}
